@@ -1,4 +1,5 @@
 import datetime
+import locale
 import warnings
 from typing import Literal
 
@@ -1243,7 +1244,7 @@ class Inlet(BaseSectionObject):
 
     @classmethod
     def from_inp_line(cls, name, kind, *line_args):
-        return _INLET_DICT[kind].from_inp_line(name, kind, *line_args)
+        return _INLET_DICT[kind](name, kind, *line_args)
 
 
 class InletGrate(Inlet):
@@ -1583,6 +1584,14 @@ class TimeseriesData(Timeseries):
         else:
             str_only = False
         try:
+            loc = locale.getlocale()
+
+            # use default locale for SWMM dates
+            try:
+                locale.setlocale(locale.LC_TIME, 'en_US.utf8')  # works for windows and linux
+            except locale.Error:
+                locale.setlocale(locale.LC_TIME, 'en_US.UTF-8')  # works for mac
+
             for dt in date_time:
                 if isinstance(dt, (pd.Timestamp, datetime.datetime)):
                     date_time_new.append(dt)
@@ -1599,9 +1608,11 @@ class TimeseriesData(Timeseries):
             if str_only:
                 date_time_new = pd.to_datetime(date_time_new, format='%m/%d/%Y %H:%M:%S')
 
+            locale.setlocale(locale.LC_TIME, loc)  # restore saved locale
             self.data = list(zip(date_time_new, values))
-        except:
+        except Exception as e:
             # if the conversion doesn't work - skip it
+            # maybe the locale is not available
             warnings.warn(f'Could not convert Data for Timeseries(Name={self.name}). First datetime = "{date_time[0]}"')
 
     @property
